@@ -1,11 +1,82 @@
 """
 Package where filters related to the learning architectural subdomain are implemented.
 """
+
 from openedx_filters.exceptions import OpenEdxFilterException
 from openedx_filters.tooling import OpenEdxPublicFilter
 from openedx_filters.utils import SensitiveDataManagementMixin
 
 
+class AccountSettingsRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create Account settings filters.
+    """
+
+    filter_type = "org.openedx.learning.student.settings.render.started.v1"
+
+    class RedirectToPage(OpenEdxFilterException):
+        """
+        Custom class used to redirect before the account settings rendering process.
+        """
+
+        def __init__(self, message, redirect_to=""):
+            """
+            Override init that defines specific arguments used in the account settings render process.
+
+            Arguments:
+                message: error message for the exception.
+                redirect_to: URL to redirect to.
+            """
+            super().__init__(message, redirect_to=redirect_to)
+
+    class RenderInvalidAccountSettings(OpenEdxFilterException):
+        """
+        Custom class used to stop the account settings rendering process.
+        """
+
+        def __init__(self, message, account_settings_template="", template_context=None):
+            """
+            Override init that defines specific arguments used in the account settings render process.
+
+            Arguments:
+                message: error message for the exception.
+                account_settings_template: template path rendered instead.
+                template_context: context used to the new account settings template.
+            """
+            super().__init__(
+                message,
+                account_settings_template=account_settings_template,
+                template_context=template_context,
+            )
+
+    class RenderCustomResponse(OpenEdxFilterException):
+        """
+        Custom class used to stop the account settings rendering process and return a custom response.
+        """
+
+        def __init__(self, message, response=None):
+            """
+            Override init that defines specific arguments used in the account settings render process.
+
+            Arguments:
+                message: error message for the exception.
+                response: custom response which will be returned by the account settings view.
+            """
+            super().__init__(message, response=response)
+
+    @classmethod
+    def run_filter(cls, context, template_name):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+            context (dict): template context for the account settings page.
+            template_name (str): template path used to render the account settings page.
+        """
+        data = super().run_pipeline(context=context, template_name=template_name)
+        return data.get("context"), data.get("template_name")
+
+
 class StudentRegistrationRequested(OpenEdxPublicFilter, SensitiveDataManagementMixin):
     """
     Custom class used to create registration filters and its custom methods.
@@ -498,3 +569,96 @@ class VerticalBlockRenderCompleted(OpenEdxPublicFilter):
         """
         data = super().run_pipeline(block=block, fragment=fragment, context=context, view=view)
         return data.get("block"), data.get("fragment"), data.get("context"), data.get("view")
+
+
+class CourseHomeUrlCreationStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create filters to act on course home url creation.
+    """
+
+    filter_type = "org.openedx.learning.course.homepage.url.creation.started.v1"
+
+    @classmethod
+    def run_filter(cls, course_key, course_home_url):
+        """
+        Execute a filter with the specified signature.
+
+        Arguments:
+            course_key (CourseKey): The course key for which the home url is being requested.
+            course_home_url (String): The url string for the course home
+        """
+        data = super().run_pipeline(course_key=course_key, course_home_url=course_home_url)
+        return data.get("course_key"), data.get("course_home_url")
+
+
+class InstructorDashboardRenderStarted(OpenEdxPublicFilter):
+    """
+    Custom class used to create instructor dashboard filters and its custom methods.
+    """
+
+    filter_type = "org.openedx.learning.instructor.dashboard.render.started.v1"
+
+    class RedirectToPage(OpenEdxFilterException):
+        """
+        Custom class used to stop the instructor dashboard render by redirecting to a new page.
+        """
+
+        def __init__(self, message, redirect_to=""):
+            """
+            Override init that defines specific arguments used in the instructor dashboard render process.
+
+            Arguments:
+                message: error message for the exception.
+                redirect_to: URL to redirect to.
+            """
+            super().__init__(message, redirect_to=redirect_to)
+
+    class RenderInvalidDashboard(OpenEdxFilterException):
+        """
+        Custom class used to render a custom template instead of the instructor dashboard.
+        """
+
+        def __init__(self, message, instructor_template="", template_context=None):
+            """
+            Override init that defines specific arguments used in the instructor dashboard render process.
+
+            Arguments:
+                message: error message for the exception.
+                instructor_template: template path rendered instead.
+                template_context: context used to the new instructor_template.
+            """
+            super().__init__(
+                message,
+                instructor_template=instructor_template,
+                template_context=template_context,
+            )
+
+    class RenderCustomResponse(OpenEdxFilterException):
+        """
+        Custom class used to stop the instructor dashboard rendering by returning a custom response.
+        """
+
+        def __init__(self, message, response=None):
+            """
+            Override init that defines specific arguments used in the instructor dashboard render process.
+
+            Arguments:
+                message: error message for the exception.
+                response: custom response which will be returned by the dashboard view.
+            """
+            super().__init__(
+                message,
+                response=response,
+            )
+
+    @classmethod
+    def run_filter(cls, context, template_name):
+        """
+        Execute a filter with the signature specified.
+
+        Arguments:
+            context (dict): context dictionary for instructor's tab template.
+            template_name (str): template name to be rendered by the instructor's tab.
+        """
+        data = super().run_pipeline(context=context, template_name=template_name)
+        return data.get("context"), data.get("template_name")
