@@ -7,6 +7,7 @@ from ddt import data, ddt, unpack
 from django.test import TestCase
 
 from openedx_filters.learning.filters import (
+    AccountSettingsRenderStarted,
     CertificateCreationRequested,
     CertificateRenderStarted,
     CohortAssignmentRequested,
@@ -14,8 +15,10 @@ from openedx_filters.learning.filters import (
     CourseAboutRenderStarted,
     CourseEnrollmentQuerysetRequested,
     CourseEnrollmentStarted,
+    CourseHomeUrlCreationStarted,
     CourseUnenrollmentStarted,
     DashboardRenderStarted,
+    InstructorDashboardRenderStarted,
     StudentLoginRequested,
     StudentRegistrationRequested,
     VerticalBlockChildRenderStarted,
@@ -309,6 +312,7 @@ class TestRenderingFilters(TestCase):
     - DashboardRenderStarted
     - VerticalBlockChildRenderStarted
     - VerticalBlockRenderCompleted
+    - AccountSettingsRenderStarted
     """
 
     def setUp(self):
@@ -472,6 +476,74 @@ class TestRenderingFilters(TestCase):
 
         self.assertDictContainsSubset(attributes, exception.__dict__)
 
+    def test_account_settings_render_started(self):
+        """
+        Test AccountSettingsRenderStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter should return context.
+        """
+        context = {
+            'duplicate_provider': None,
+            'disable_courseware_js': True,
+            'show_dashboard_tabs': True
+        }
+
+        result, _ = AccountSettingsRenderStarted.run_filter(context=context, template_name=None)
+
+        self.assertEqual(result, context)
+
+    @data(
+        (AccountSettingsRenderStarted.RedirectToPage, {"redirect_to": "custom_account_settings.html"}),
+        (AccountSettingsRenderStarted.RenderInvalidAccountSettings, {}),
+        (AccountSettingsRenderStarted.RenderCustomResponse, {"response": Mock()})
+    )
+    @unpack
+    def test_halt_account_rendering_process(self, AccountSettingsException, attributes):
+        """
+        Test for account settings exceptions attributes.
+        Expected behavior:
+            - The exception must have the attributes specified.
+        """
+        exception = AccountSettingsException(message="You can't access this page", **attributes)
+
+        self.assertDictContainsSubset(attributes, exception.__dict__)
+
+    def test_instructor_dashboard_render_started(self):
+        """
+        Test InstructorDashboardRenderStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter must have the signature specified.
+            - The filter should return context and template_name in that order.
+        """
+        result = InstructorDashboardRenderStarted.run_filter(self.context, self.template_name)
+
+        self.assertTupleEqual((self.context, self.template_name,), result)
+
+    @data(
+        (InstructorDashboardRenderStarted.RedirectToPage, {"redirect_to": "custom-dashboard.html"}),
+        (
+            InstructorDashboardRenderStarted.RenderInvalidDashboard,
+            {
+                "instructor_template": "custom-dasboard.html",
+                "template_context": {"course": Mock()},
+            }
+        ),
+        (InstructorDashboardRenderStarted.RenderCustomResponse, {"response": Mock()}),
+    )
+    @unpack
+    def test_halt_instructor_dashboard_render(self, dashboard_exception, attributes):
+        """
+        Test for the instructor dashboard exceptions attributes.
+
+        Expected behavior:
+            - The exception must have the attributes specified.
+        """
+        exception = dashboard_exception(message="You can't access the dashboard", **attributes)
+
+        self.assertDictContainsSubset(attributes, exception.__dict__)
+
 
 class TestCohortFilters(TestCase):
     """
@@ -509,3 +581,26 @@ class TestCohortFilters(TestCase):
         result = CohortAssignmentRequested.run_filter(user, target_cohort)
 
         self.assertTupleEqual((user, target_cohort,), result)
+
+
+class TestFederatedContentFilters(TestCase):
+    """
+    Test class to verify standard behavior of the federated content filters.
+    You'll find test suites for:
+
+    - CourseHomeUrlCreationStarted
+    """
+
+    def test_course_homeurl_creation_started(self):
+        """
+        Test CourseHomeUrlCreationStarted filter behavior under normal conditions.
+
+        Expected behavior:
+            - The filter must have the signature specified.
+            - The filter should return course_key and course_home_url in that order.
+        """
+        course_key, course_home_url = Mock(), Mock()
+
+        result = CourseHomeUrlCreationStarted.run_filter(course_key, course_home_url)
+
+        self.assertTupleEqual((course_key, course_home_url,), result)
